@@ -47,10 +47,9 @@ static void     pk_transaction_db_finalize	(GObject        *object);
 
 #define PK_TRANSACTION_DB_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PK_TYPE_TRANSACTION_DB, PkTransactionDbPrivate))
 
-#define PK_TRANSACTION_DB_ID_FILE_OBSOLETE	LOCALSTATEDIR "/lib/PackageKit/job_count.dat"
-
 struct PkTransactionDbPrivate
 {
+	gboolean		 loaded;
 	sqlite3			*db;
 	guint			 job_count;
 	guint			 database_save_id;
@@ -227,7 +226,6 @@ pk_transaction_db_action_time_since (PkTransactionDb *tdb, PkRoleEnum role)
 	g_return_val_if_fail (tdb->priv->db != NULL, 0);
 
 	role_text = pk_role_enum_to_string (role);
-	g_debug ("get_time_since_action=%s", role_text);
 
 	statement = g_strdup_printf ("SELECT timespec FROM last_action WHERE role = '%s'", role_text);
 	rc = sqlite3_exec (tdb->priv->db, statement, pk_time_action_sqlite_callback, &timespec, &error_msg);
@@ -237,14 +235,11 @@ pk_transaction_db_action_time_since (PkTransactionDb *tdb, PkRoleEnum role)
 		sqlite3_free (error_msg);
 		return G_MAXUINT;
 	}
-	if (timespec == NULL) {
-		g_debug ("no response, assume maximum value");
+	if (timespec == NULL)
 		return G_MAXUINT;
-	}
 
 	/* work out the difference */
 	time_ms = pk_transaction_db_iso8601_difference (timespec);
-	g_debug ("timespec=%s, difference=%i", timespec, time_ms);
 	g_free (timespec);
 
 	return time_ms;
@@ -273,10 +268,8 @@ pk_transaction_db_action_time_reset (PkTransactionDb *tdb, PkRoleEnum role)
 	/* get the previous entry */
 	since = pk_transaction_db_action_time_since (tdb, role);
 	if (since == G_MAXUINT) {
-		g_debug ("set action time=%s to %s", role_text, timespec);
 		statement = g_strdup_printf ("INSERT INTO last_action (role, timespec) VALUES ('%s', '%s')", role_text, timespec);
 	} else {
-		g_debug ("reset action time=%s to %s", role_text, timespec);
 		statement = g_strdup_printf ("UPDATE last_action SET timespec = '%s' WHERE role = '%s'", timespec, role_text);
 	}
 
@@ -342,8 +335,6 @@ pk_transaction_db_add (PkTransactionDb *tdb, const gchar *tid)
 
 	g_return_val_if_fail (PK_IS_TRANSACTION_DB (tdb), FALSE);
 
-	g_debug ("adding transaction %s", tid);
-
 	timespec = pk_iso8601_present ();
 	statement = g_strdup_printf ("INSERT INTO transactions (transaction_id, timespec) VALUES ('%s', '%s')", tid, timespec);
 	pk_transaction_db_sql_statement (tdb, statement);
@@ -521,25 +512,29 @@ pk_transaction_db_defer_write_job_count_cb (PkTransactionDb *tdb)
 	gchar *error_msg = NULL;
 	gint rc;
 
+	/* not loaded! */
+	if (tdb->priv->db == NULL) {
+		g_warning ("PkTransactionDb not loaded");
+		goto out;
+	}
+
 	/* force fsync as we don't want to repeat this number */
 	sqlite3_exec (tdb->priv->db, "PRAGMA synchronous=ON", NULL, NULL, NULL);
 
 	/* save the job count */
-	g_debug ("doing deferred write syncronous");
-	statement = g_strdup_printf ("UPDATE config SET value = '%i' WHERE key = 'job_count'", tdb->priv->job_count);
+	statement = g_strdup_printf ("UPDATE config SET value = '%i' WHERE key = 'job_count'",
+				     tdb->priv->job_count);
 	rc = sqlite3_exec (tdb->priv->db, statement, NULL, NULL, &error_msg);
 	if (rc != SQLITE_OK) {
-		g_error ("failed to set job id: %s\n", error_msg);
+		g_warning ("failed to set job id: %s\n", error_msg);
 		sqlite3_free (error_msg);
 		goto out;
 	}
 
 	/* turn off fsync */
 	sqlite3_exec (tdb->priv->db, "PRAGMA synchronous=OFF", NULL, NULL, NULL);
-
-	/* allow this to happen again */
-	tdb->priv->database_save_id = 0;
 out:
+	tdb->priv->database_save_id = 0;
 	g_free (statement);
 	return FALSE;
 }
@@ -560,7 +555,6 @@ pk_transaction_db_generate_id (PkTransactionDb *tdb)
 	/* we don't need to wait for the database write, just do this the
 	 * next time we are idle (but ensure we do this on shutdown) */
 	if (tdb->priv->database_save_id == 0) {
-		g_debug ("deferring low priority write until idle");
 		tdb->priv->database_save_id =
 			g_idle_add_full (G_PRIORITY_LOW, (GSourceFunc)
 					 pk_transaction_db_defer_write_job_count_cb, tdb, NULL);
@@ -673,10 +667,8 @@ pk_transaction_db_get_proxy (PkTransactionDb *tdb, guint uid, const gchar *sessi
 	}
 
 	/* nothing matched */
-	if (!item->set) {
-		g_debug ("no data");
+	if (!item->set)
 		goto out;
-	}
 
 	/* success, even if we got no data */
 	ret = TRUE;
@@ -891,9 +883,13 @@ pk_transaction_db_load (PkTransactionDb *tdb, GError **error)
 
 	g_return_val_if_fail (PK_IS_TRANSACTION_DB (tdb), FALSE);
 
-	g_debug ("trying to open database '%s'", PK_TRANSACTION_DB_FILE);
-	pk_transaction_db_ensure_file_directory (PK_TRANSACTION_DB_FILE);
-	rc = sqlite3_open (PK_TRANSACTION_DB_FILE, &tdb->priv->db);
+	/* already loaded */
+	if (tdb->priv->loaded)
+		return TRUE;
+
+	g_debug ("trying to open database '%s'", PK_DB_DIR "/transactions.db");
+	pk_transaction_db_ensure_file_directory (PK_DB_DIR "/transactions.db");
+	rc = sqlite3_open (PK_DB_DIR "/transactions.db", &tdb->priv->db);
 	if (rc != SQLITE_OK) {
 		ret = FALSE;
 		g_set_error (error,
@@ -929,21 +925,6 @@ pk_transaction_db_load (PkTransactionDb *tdb, GError **error)
 			goto out;
 	}
 
-	/* check transactions has enough data (since 0.3.11) */
-	ret = pk_transaction_db_execute (tdb, "SELECT uid, cmdline FROM transactions LIMIT 1", &error_local);
-	if (!ret) {
-		g_debug ("altering table to repair: %s", error_local->message);
-		g_clear_error (&error_local);
-		statement = "ALTER TABLE transactions ADD COLUMN uid INTEGER DEFAULT 0;";
-		ret = pk_transaction_db_execute (tdb, statement, error);
-		if (!ret)
-			goto out;
-		statement = "ALTER TABLE transactions ADD COLUMN cmdline TEXT;";
-		ret = pk_transaction_db_execute (tdb, statement, error);
-		if (!ret)
-			goto out;
-	}
-
 	/* check last_action (since 0.3.10) */
 	ret = pk_transaction_db_execute (tdb, "SELECT * FROM last_action LIMIT 1", &error_local);
 	if (!ret) {
@@ -966,21 +947,8 @@ pk_transaction_db_load (PkTransactionDb *tdb, GError **error)
 		if (!ret)
 			goto out;
 
-		/* save creation version */
-		text = g_strdup_printf ("INSERT INTO config (key, value) VALUES ('version', '%s')", PACKAGE_VERSION);
-		ret = pk_transaction_db_execute (tdb, text, error);
-		if (!ret)
-			goto out;
-		g_free (text);
-
-		/* get the old job count from the text file (this is a legacy file) */
-		ret = g_file_get_contents (PK_TRANSACTION_DB_ID_FILE_OBSOLETE, &text, NULL, NULL);
-		if (ret)
-			pk_strtouint (text, &tdb->priv->job_count);
-		g_free (text);
-
 		/* save job id */
-		text = g_strdup_printf ("INSERT INTO config (key, value) VALUES ('job_count', '%i')", tdb->priv->job_count);
+		text = g_strdup_printf ("INSERT INTO config (key, value) VALUES ('job_count', '%i')", 1);
 		ret = pk_transaction_db_execute (tdb, text, error);
 		if (!ret)
 			goto out;
@@ -1009,30 +977,8 @@ pk_transaction_db_load (PkTransactionDb *tdb, GError **error)
 			goto out;
 	}
 
-	/* session no_proxy proxy */
-	ret = pk_transaction_db_execute (tdb, "SELECT no_proxy FROM proxy LIMIT 1", &error_local);
-	if (!ret) {
-		g_debug ("altering table to repair: %s", error_local->message);
-		g_clear_error (&error_local);
-		statement = "ALTER TABLE proxy ADD COLUMN proxy_https TEXT;";
-		ret = pk_transaction_db_execute (tdb, statement, error);
-		if (!ret)
-			goto out;
-		statement = "ALTER TABLE proxy ADD COLUMN proxy_socks TEXT;";
-		ret = pk_transaction_db_execute (tdb, statement, error);
-		if (!ret)
-			goto out;
-		statement = "ALTER TABLE proxy ADD COLUMN no_proxy TEXT;";
-		ret = pk_transaction_db_execute (tdb, statement, error);
-		if (!ret)
-			goto out;
-		statement = "ALTER TABLE proxy ADD COLUMN pac TEXT;";
-		ret = pk_transaction_db_execute (tdb, statement, error);
-		if (!ret)
-			goto out;
-	}
-
 	/* success */
+	tdb->priv->loaded = TRUE;
 	ret = TRUE;
 out:
 	return ret;
